Module groups

Module groups 

Helper types & constants for working with groups.

Constants

FIRST_KERNING_GROUP_PREFIX
The UFO standard group prefix for kerns in the first position.
SECOND_KERNING_GROUP_PREFIX
The UFO standard group prefix for kerns in the second position.

Type Aliases

Groups
A map of group name to a list of glyph names.